@@ -262,10 +262,25 @@ def all_operations():
     return all_ops
 
 
+def get_name_of_function(func):
+    """
+    Searches all functions for a given function
+    and returns its human-readable name
+    """
+    for k, v in all_operations().items():
+        if v is func:
+            if ">" in k:
+                return k.split(">")[1]
+            else:
+                return k
+    return None
+
+
 def collect_from_pyclesperanto_if_installed():
     """
     Collect all functions from clesperanto that are annotated with "in assistant"
     """
+    from napari_time_slicer import time_slicer
     try:
         import pyclesperanto_prototype as cle
     except ImportError:
@@ -278,7 +293,7 @@ def collect_from_pyclesperanto_if_installed():
         if not callable(c):
             choices = cle.operations(['in assistant'] + list(c.include), c.exclude)
             for choice, func in choices.items():
-                result[c.tools_menu + ">" + choice + " (clesperanto)"] = func
+                result[c.tools_menu + ">" + choice + " (clesperanto)"] = time_slicer(func)
 
     return result
 
@@ -330,6 +345,10 @@ def collect_from_tools_menu_if_installed():
 
 
 def collect_from_npe2_if_installed():
+    """
+    Collect all functions provided by the NPE2 interface (napari) which contain
+    a menu name
+    """
     try:
         import npe2
     except ImportError:
@@ -453,6 +472,20 @@ def find_function(op_name):
     return found_function
 
 
+def get_category_of_function(func):
+    """
+    Searches categories for a given function and returns the first (!)
+    category that contains the function
+    """
+    func_name = get_name_of_function(func)
+    for k, c in CATEGORIES.items():
+        if not callable(c):
+            ops = operations_in_menu(c)
+            if func_name in ops:
+                return c
+    return None
+
+
 def filter_categories(search_string: str = ""):
     """Return all categories that have a function that contains a
     given search string in their name.
